@@ -16,7 +16,7 @@ import glob
 import logging
 import os
 import subprocess
-from typing import List, Optional, Tuple
+from typing import Optional
 
 import docopt
 import pytest
@@ -33,7 +33,7 @@ logger = logging.getLogger(__name__)
 
 class TestProcessDataset:
     @pytest.fixture
-    def setup(self, tmp_path) -> Tuple[str, str]:
+    def setup(self, tmp_path) -> tuple[str, str]:
         # Suppress RDKit warnings to clean up the test output.
         RDLogger.logger().setLevel(RDLogger.CRITICAL)
         reaction1 = reaction_pb2.Reaction()
@@ -121,7 +121,7 @@ class TestSubmissionWorkflow:
     _DEFAULT_BRANCH = "main"
 
     @pytest.fixture
-    def setup(self, tmp_path) -> Tuple[str, str]:
+    def setup(self, tmp_path) -> tuple[str, str]:
         test_subdirectory = tmp_path.as_posix()
         os.chdir(test_subdirectory)
         subprocess.run(["git", "init", "-b", self._DEFAULT_BRANCH], check=True)
@@ -153,7 +153,7 @@ class TestSubmissionWorkflow:
         subprocess.run(["git", "checkout", "-b", "test"], check=True)
         yield test_subdirectory, dataset_filename
 
-    def _run(self, test_subdirectory: str, extra_argv: Optional[List[str]] = None):
+    def _run(self, test_subdirectory: str, extra_argv: Optional[list[str]] = None):
         """Runs process_dataset.main().
 
         Args:
